"""
Copyright (c) 2011-2017, Agora Games, LLC All rights reserved.

https://github.com/agoragames/chai/blob/master/LICENSE.txt
"""

from __future__ import absolute_import
__version__ = '1.1.2'
from .chai import Chai
